@@ -4,7 +4,25 @@ import requests, json, os, subprocess, time
 import click, hashlib, pathlib, shutil
 from datetime import datetime
 
-@cli.command()
+@cli.group(invoke_without_command=True)
+@click.pass_context
+def backup(ctx):
+	'''Create, restore and manage application backups'''
+	# Default subcommand for back-compat
+	if not ctx.invoked_subcommand:
+		return ctx.forward(create)
+
+@cli.command(name='restore')
+@click.argument('path', nargs=1, required=True)
+@click.option('--yes', '-y', is_flag=True, help='Skip the AYS message and force yes')
+@click.option('--skip-db', is_flag=True, help='Do not import the database')
+@click.option('--skip-uploads', is_flag=True, help='Do not import uploads')
+@click.pass_context
+def restore_compat(ctx, path, yes, skip_db, skip_uploads):
+	'''Restore your application files, uploads and database from a backup file'''
+	return ctx.forward(restore)
+
+@backup.command()
 @click.argument('path', nargs=1, required=True)
 @click.option('--yes', '-y', is_flag=True, help='Skip the AYS message and force yes')
 @click.option('--skip-db', is_flag=True, help='Do not import the database')
@@ -17,18 +35,18 @@ def restore(path, yes, skip_db, skip_uploads):
 
 	path = pathlib.Path(path)
 	if not path.exists():
-		raise click.ClickException('File does not exist')
+		raise util.SailException('File does not exist')
 
 	if path.name.endswith('.sql.gz') or path.name.endswith('.sql'):
-		raise click.ClickException('Looks like a database-only backup. Try: sail db import')
+		raise util.SailException('Looks like a database-only backup. Try: sail db import')
 
 	if not path.name.endswith('.tar.gz'):
-		raise click.ClickException('Doesn\'t look like a backup file')
+		raise util.SailException('Doesn\'t look like a backup file')
 
 	if not yes:
 		click.confirm('This will restore a full backup to production. Continue?', abort=True)
 
-	click.echo('# Restoring backup')
+	util.heading('Restoring local backup')
 
 	app_id = config['app_id']
 	backups_dir = pathlib.Path(root + '/.backups')
@@ -39,7 +57,7 @@ def restore(path, yes, skip_db, skip_uploads):
 
 	database_filename = 'database.%s.sql.gz' % hashlib.sha256(os.urandom(32)).hexdigest()[:8]
 
-	click.echo('- Extracting backup files')
+	util.item('Extracting backup files')
 
 	p = subprocess.Popen([
 		'tar', ('-xzvf' if util.debug() else '-xzf'), path.resolve(), '--directory', progress_dir.resolve()
@@ -50,17 +68,17 @@ def restore(path, yes, skip_db, skip_uploads):
 
 	if p.returncode != 0:
 		shutil.rmtree(progress_dir)
-		raise click.ClickException('An error occurred during backup. Please try again.')
+		raise util.SailException('An error occurred during backup. Please try again.')
 
 	for x in progress_dir.iterdir():
 		if x.name not in ['www', 'database.sql.gz', 'uploads']:
 			shutil.rmtree(progress_dir)
-			raise click.ClickException('Unexpected file in backup archive: %s' % x.name)
+			raise util.SailException('Unexpected file in backup archive: %s' % x.name)
 
 	if skip_uploads:
-		click.echo('- Skipping uploads')
+		util.item('Skipping uploads')
 	else:
-		click.echo('- Importing uploads')
+		util.item('Importing uploads')
 
 		args = ['-rtl', '--delete', '--rsync-path', 'sudo -u www-data rsync']
 		source = '%s/uploads/' % progress_dir
@@ -69,9 +87,9 @@ def restore(path, yes, skip_db, skip_uploads):
 
 		if returncode != 0:
 			shutil.rmtree(progress_dir)
-			raise click.ClickException('An error occurred during restore. Please try again.')
+			raise util.SailException('An error occurred during restore. Please try again.')
 
-	click.echo('- Importing application files')
+	util.item('Importing application files')
 
 	args = ['-rtl', '--delete', '--rsync-path', 'sudo -u www-data rsync']
 	source = '%s/www/' % progress_dir
@@ -80,12 +98,12 @@ def restore(path, yes, skip_db, skip_uploads):
 
 	if returncode != 0:
 		shutil.rmtree(progress_dir)
-		raise click.ClickException('An error occurred during restore. Please try again.')
+		raise util.SailException('An error occurred during restore. Please try again.')
 
 	if skip_db:
-		click.echo('- Skipping database import')
+		util.item('Skipping database import')
 	else:
-		click.echo('- Uploading database backup')
+		util.item('Uploading database backup')
 
 		args = ['-t']
 		source = '%s/database.sql.gz' % progress_dir
@@ -94,9 +112,9 @@ def restore(path, yes, skip_db, skip_uploads):
 
 		if returncode != 0:
 			shutil.rmtree(progress_dir)
-			raise click.ClickException('An error occurred in rsync. Please try again.')
+			raise util.SailException('An error occurred in rsync. Please try again.')
 
-		click.echo('- Importing database into MySQL')
+		util.item('Importing database into MySQL')
 
 		# TODO: Maybe do an atomic import which deletes tables that no longer exist
 		# by doing a rename.
@@ -104,27 +122,28 @@ def restore(path, yes, skip_db, skip_uploads):
 			c.run('zcat %s/%s | mysql -uroot "wordpress_%s"' % (remote_path, database_filename, config['namespace']))
 		except:
 			shutil.rmtree(progress_dir)
-			raise click.ClickException('An error occurred in SSH. Please try again.')
+			raise util.SailException('An error occurred in SSH. Please try again.')
 
-		click.echo('- Cleaning up production')
+		util.item('Cleaning up production')
 
 		try:
 			c.run('rm %s/%s' % (remote_path, database_filename)) # TODO: Move to /tmp maybe, or /root
 		except:
 			shutil.rmtree(progress_dir)
-			raise click.ClickException('An error occurred in SSH. Please try again.')
+			raise util.SailException('An error occurred in SSH. Please try again.')
 
 	shutil.rmtree(progress_dir)
-	click.echo('- Backup restored successfully. Your local copy may be out of date.')
 
-@cli.command()
-def backup():
+	util.success('Backup restored successfully. Local copy may be out of date.')
+
+@backup.command()
+def create():
 	'''Backup your production files and database to your local .backups directory'''
 	root = util.find_root()
 	config = util.config()
 	c = util.connection()
 
-	click.echo('# Backing up')
+	util.heading('Creating a local backup')
 
 	app_id = config['app_id']
 	backups_dir = pathlib.Path(root + '/.backups')
@@ -136,7 +155,7 @@ def backup():
 
 	database_filename = 'database.%s.sql.gz' % hashlib.sha256(os.urandom(32)).hexdigest()[:8]
 
-	click.echo('- Downloading application files')
+	util.item('Downloading application files')
 
 	args = ['-rtl', '--copy-dest', '%s/' % root]
 	source = 'root@%s:%s/public/' % (config['hostname'], remote_path)
@@ -145,9 +164,9 @@ def backup():
 
 	if returncode != 0:
 		shutil.rmtree(progress_dir)
-		raise click.ClickException('An error occurred during backup. Please try again.')
+		raise util.SailException('An error occurred during backup. Please try again.')
 
-	click.echo('- Downloading uploads')
+	util.item('Downloading uploads')
 
 	args = ['-rtl', '--copy-dest', '%s/wp-content/uploads/' % root]
 	source = 'root@%s:%s/uploads/' % (config['hostname'], remote_path)
@@ -156,17 +175,17 @@ def backup():
 
 	if returncode != 0:
 		shutil.rmtree(progress_dir)
-		raise click.ClickException('An error occurred during backup. Please try again.')
+		raise util.SailException('An error occurred during backup. Please try again.')
 
-	click.echo('- Exporting WordPress database')
+	util.item('Exporting WordPress database')
 
 	try:
 		c.run('mysqldump --quick --single-transaction --default-character-set=utf8mb4 -uroot "wordpress_%s" | gzip -c9 > %s/%s' % (config['namespace'], remote_path, database_filename))
 	except:
 		shutil.rmtree(progress_dir)
-		raise click.ClickException('An error occurred in SSH. Please try again.')
+		raise util.SailException('An error occurred in SSH. Please try again.')
 
-	click.echo('- Export completed, downloading database')
+	util.item('Export completed, downloading database')
 
 	args = ['-t']
 	source = 'root@%s:%s/%s' % (config['hostname'], remote_path, database_filename)
@@ -175,32 +194,32 @@ def backup():
 
 	if returncode != 0:
 		shutil.rmtree(progress_dir)
-		raise click.ClickException('An error occurred in rsync. Please try again.')
+		raise util.SailException('An error occurred in rsync. Please try again.')
 
-	click.echo('- Cleaning up production')
+	util.item('Cleaning up production')
 
 	try:
 		c.run('rm %s/%s' % (remote_path, database_filename))
 	except:
 		shutil.rmtree(progress_dir)
-		raise click.ClickException('An error occurred in SSH. Please try again.')
+		raise util.SailException('An error occurred in SSH. Please try again.')
 
 	timestamp = datetime.now().strftime('%Y-%m-%d-%H%M%S.tar.gz')
 	target = pathlib.Path(backups_dir / timestamp)
 
-	click.echo('- Archiving and compressing backup files')
+	util.item('Archiving and compressing backup files')
 
 	p = subprocess.Popen([
 		'tar', ('-cvzf' if util.debug() else '-czf'), target.resolve(), '-C', progress_dir.resolve(), '.'
 	])
 
 	while p.poll() is None:
-		util.loader()
+		pass
 
 	if p.returncode != 0:
 		shutil.rmtree(progress_dir)
-		raise click.ClickException('An error occurred during backup. Please try again.')
+		raise util.SailException('An error occurred during backup. Please try again.')
 
 	shutil.rmtree(progress_dir)
 
-	click.echo('- Backup completed at .backups/%s' % timestamp)
+	util.success('Backup completed at .backups/%s' % timestamp)
