@@ -142,6 +142,8 @@ def init(ctx, provider_token, email, size, region, force, namespace, environment
 	# Run the installs
 	_install(passwords)
 
+	c = util.connection()
+
 	# Add the default WP cron schedule.
 	ctx.invoke(cron.add, schedule='*/5', command=('wp cron event run --due-now',), quiet=True)
 
@@ -149,6 +151,8 @@ def init(ctx, provider_token, email, size, region, force, namespace, environment
 	if blueprint and blueprint != 'no' and blueprint != 'none':
 		try:
 			ctx.invoke(blueprints.blueprint, path=[blueprint], doing_init=True)
+			remote_path = util.remote_path()
+			c.run(f'sudo -u www-data wp --path={remote_path}/public option get home')
 		except:
 			util.item('Could not apply blueprint')
 
@@ -408,16 +412,21 @@ def _configure():
 	util.wait(wait_for_cloud_init, timeout=900, interval=10)
 
 	c.run('mkdir -p /etc/nginx/conf.d/extras')
-	c.put(sail.TEMPLATES_PATH + '/nginx.main.conf', '/etc/nginx/nginx.conf')
-	c.put(sail.TEMPLATES_PATH + '/nginx.shared.conf', '/etc/nginx/conf.d/extras/sail.conf')
-	c.put(sail.TEMPLATES_PATH + '/nginx.certbot.conf', '/etc/nginx/conf.d/extras/certbot.conf')
-	c.put(sail.TEMPLATES_PATH + '/prepend.php', '/etc/sail/prepend.php')
-	c.put(sail.TEMPLATES_PATH + '/php.ini', '/etc/php/7.4/fpm/php.ini')
-	c.put(sail.TEMPLATES_PATH + '/php.ini', '/etc/php/7.4/cli/php.ini')
+	c.put(sail.TEMPLATES_PATH + '/nginx.main.conf', '/etc/nginx/nginx.conf', preserve_mode=False)
+	c.put(sail.TEMPLATES_PATH + '/nginx.shared.conf', '/etc/nginx/conf.d/extras/sail.conf', preserve_mode=False)
+	c.put(sail.TEMPLATES_PATH + '/nginx.certbot.conf', '/etc/nginx/conf.d/extras/certbot.conf', preserve_mode=False)
+	c.put(sail.TEMPLATES_PATH + '/prepend.php', '/etc/sail/prepend.php', preserve_mode=False)
+	c.put(sail.TEMPLATES_PATH + '/php.ini', '/etc/php/7.4/fpm/php.ini', preserve_mode=False)
+	c.put(sail.TEMPLATES_PATH + '/php.ini', '/etc/php/7.4/cli/php.ini', preserve_mode=False)
+	c.put(sail.TEMPLATES_PATH + '/mariadb.cnf', '/etc/mysql/mariadb.conf.d/90-sail.cnf', preserve_mode=False)
+	c.put(sail.TEMPLATES_PATH + '/logrotate.conf', '/etc/logrotate.d/sail', preserve_mode=False)
 
 	# Make sure certbot.conf is in action.
 	c.run('systemctl reload nginx')
 
+	# Make sure MariaDB config is active.
+	c.run('systemctl restart mariadb.service')
+
 	# Get xhprof
 	c.run('curl -L https://github.com/kovshenin/xhprof/releases/download/0.10.2-sail/xhprof.so.gz -o /tmp/xhprof.so.gz')
 	c.run('gunzip /tmp/xhprof.so.gz && mv /tmp/xhprof.so /usr/lib/php/20190902/xhprof.so')
@@ -534,6 +543,11 @@ def destroy(yes, environment, skip_dns):
 	if not yes:
 		click.confirm('All application data will be scrubbed and irretrievable. Are you sure?', abort=True)
 
+	# Prevent destroying applications with added domains.
+	user_domains = [d['name'] for d in config.get('domains', []) if not d.get('internal')]
+	if len(user_domains) > 0:
+		raise util.SailException('Remove the following domains first: %s' % ', '.join(user_domains))
+
 	util.heading('Destroying application')
 
 	namespaces = []
